==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/systemequipment_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.systemequipment_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.systemequipment_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.systemequipment_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link SystemEquipment }
     * 
     * @return
     *     the new instance of {@link SystemEquipment }
     */
    public SystemEquipment createSystemEquipment() {
        return new SystemEquipment();
    }

    /**
     * Create an instance of {@link ChildSystem }
     * 
     * @return
     *     the new instance of {@link ChildSystem }
     */
    public ChildSystem createChildSystem() {
        return new ChildSystem();
    }

    /**
     * Create an instance of {@link SystemParentHierarchy }
     * 
     * @return
     *     the new instance of {@link SystemParentHierarchy }
     */
    public SystemParentHierarchy createSystemParentHierarchy() {
        return new SystemParentHierarchy();
    }

    /**
     * Create an instance of {@link SystemEquipment.DORMANT }
     * 
     * @return
     *     the new instance of {@link SystemEquipment.DORMANT }
     */
    public SystemEquipment.DORMANT createSystemEquipmentDORMANT() {
        return new SystemEquipment.DORMANT();
    }

    /**
     * Create an instance of {@link Variables }
     * 
     * @return
     *     the new instance of {@link Variables }
     */
    public Variables createVariables() {
        return new Variables();
    }

    /**
     * Create an instance of {@link ManufacturerInfo }
     * 
     * @return
     *     the new instance of {@link ManufacturerInfo }
     */
    public ManufacturerInfo createManufacturerInfo() {
        return new ManufacturerInfo();
    }

    /**
     * Create an instance of {@link CallCenterDetails }
     * 
     * @return
     *     the new instance of {@link CallCenterDetails }
     */
    public CallCenterDetails createCallCenterDetails() {
        return new CallCenterDetails();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     * @return
     *     the new instance of {@link UserDefinedFields }
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

    /**
     * Create an instance of {@link FacilityConditionIndex }
     * 
     * @return
     *     the new instance of {@link FacilityConditionIndex }
     */
    public FacilityConditionIndex createFacilityConditionIndex() {
        return new FacilityConditionIndex();
    }

    /**
     * Create an instance of {@link SystemEquipment.PERFORMANCEDETAILS }
     * 
     * @return
     *     the new instance of {@link SystemEquipment.PERFORMANCEDETAILS }
     */
    public SystemEquipment.PERFORMANCEDETAILS createSystemEquipmentPERFORMANCEDETAILS() {
        return new SystemEquipment.PERFORMANCEDETAILS();
    }

    /**
     * Create an instance of {@link SystemChildHierarchy }
     * 
     * @return
     *     the new instance of {@link SystemChildHierarchy }
     */
    public SystemChildHierarchy createSystemChildHierarchy() {
        return new SystemChildHierarchy();
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_entities/systemequipment_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.systemequipment_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.systemequipment_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.systemequipment_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link SystemEquipment }
     * 
     */
    public SystemEquipment createSystemEquipment() {
        return new SystemEquipment();
    }

    /**
     * Create an instance of {@link ChildSystem }
     * 
     */
    public ChildSystem createChildSystem() {
        return new ChildSystem();
    }

    /**
     * Create an instance of {@link SystemParentHierarchy }
     * 
     */
    public SystemParentHierarchy createSystemParentHierarchy() {
        return new SystemParentHierarchy();
    }

    /**
     * Create an instance of {@link Variables }
     * 
     */
    public Variables createVariables() {
        return new Variables();
    }

    /**
     * Create an instance of {@link SystemEquipment.DORMANT }
     * 
     */
    public SystemEquipment.DORMANT createSystemEquipmentDORMANT() {
        return new SystemEquipment.DORMANT();
    }

    /**
     * Create an instance of {@link ManufacturerInfo }
     * 
     */
    public ManufacturerInfo createManufacturerInfo() {
        return new ManufacturerInfo();
    }

    /**
     * Create an instance of {@link CallCenterDetails }
     * 
     */
    public CallCenterDetails createCallCenterDetails() {
        return new CallCenterDetails();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

    /**
     * Create an instance of {@link FacilityConditionIndex }
     * 
     */
    public FacilityConditionIndex createFacilityConditionIndex() {
        return new FacilityConditionIndex();
    }

    /**
     * Create an instance of {@link SystemEquipment.PERFORMANCEDETAILS }
     * 
     */
    public SystemEquipment.PERFORMANCEDETAILS createSystemEquipmentPERFORMANCEDETAILS() {
        return new SystemEquipment.PERFORMANCEDETAILS();
    }

    /**
     * Create an instance of {@link WorkflowSummaryInfo }
     * 
     */
    public WorkflowSummaryInfo createWorkflowSummaryInfo() {
        return new WorkflowSummaryInfo();
    }

    /**
     * Create an instance of {@link SystemChildHierarchy }
     * 
     */
    public SystemChildHierarchy createSystemChildHierarchy() {
        return new SystemChildHierarchy();
    }

}
